"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.typeChecker = exports.beOption = exports.beArray = exports.beInterface = exports.typeObject = exports.typeBoolean = exports.typeNumber = exports.typeString = void 0;
const assertType = (wanted) => (value) => {
    const passed = typeof value === wanted;
    const given = typeof value;
    if (!passed) {
        throw new Error(`Type is incorrect, wanted ${wanted} but given ${given}`);
    }
    return value;
};
const assertArray = (value) => {
    if (!Array.isArray(value)) {
        throw new Error('Type not an array');
    }
    return value;
};
const fieldExists = (object) => (field) => {
    const value = object[field];
    if (value === undefined) {
        throw new Error('missing value');
    }
    return value;
};
const fieldCheck = (obj) => ([field, check]) => {
    try {
        check(fieldExists(obj)(field));
    }
    catch (e) {
        const parent = e;
        throw new Error(`On field "${field}": ${parent.message}`);
    }
};
exports.typeString = assertType('string');
exports.typeNumber = assertType('number');
exports.typeBoolean = assertType('boolean');
exports.typeObject = assertType('object');
const beInterface = (checker) => (value) => {
    const obj = (0, exports.typeObject)(value);
    Object.entries(checker).forEach(fieldCheck(obj));
    return value;
};
exports.beInterface = beInterface;
const beArray = (checker) => (value) => {
    const array = assertArray(value);
    array.forEach(checker);
    return array;
};
exports.beArray = beArray;
const beOption = (checker) => (value) => {
    if (value !== undefined) {
        checker(value);
    }
    return value;
};
exports.beOption = beOption;
const typeChecker = (typeCheck) => (value) => typeCheck(value);
exports.typeChecker = typeChecker;
//# sourceMappingURL=TyCheck.js.map